#
# spec file for package gnuhealth
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014-2017 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define 	majorver 3.2
Name:           gnuhealth

# List of additional build dependencies
BuildRequires:  fdupes
BuildRequires:  python3-setuptools

Version:        %{majorver}.8
Release:        38.1

Url:            http://health.gnu.org
Source:         http://ftp.gnu.org/gnu/health/%{name}-%{version}.tar.gz
#Source:         %{name}-%{version}.tar.gz
Source1:        GNUHealth.README.SUSE
Source2:        gnuhealth-control
Source3:        gnuhealth.service
Source4:        gnuhealth-webdav@.service

BuildArch:      noarch

Summary:        A Health and Hospital Information System
License:        GPL-3.0+
Group:          Productivity/Office/Management

Requires:       proteus
Requires:       python3-PyWebDAV3-GNUHealth
Requires:       python3-caldav
Requires:       python3-cracklib
Requires:       python3-hl7apy
Requires:       python3-ldap3
Requires:       python3-polib
Requires:       python3-pyBarcode
Requires:       python3-qrcode
Requires:       python3-simpleeval
Requires:       python3-six
Requires:       python3-vobject
Requires:       trytond
Requires:       trytond_account
Requires:       trytond_account_invoice
Requires:       trytond_account_invoice_stock
Requires:       trytond_account_product
Requires:       trytond_calendar
Requires:       trytond_company
Requires:       trytond_country
Requires:       trytond_currency
Requires:       trytond_party
Requires:       trytond_product
Requires:       trytond_purchase
Requires:       trytond_purchase_request
Requires:       trytond_stock
Requires:       trytond_stock_lot
Requires:       trytond_stock_supply

# additional suggestion for a useable editor
Suggests:       nano
# you may need a frontend to work with
Suggests:       tryton

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNU Health is the Hospital Information System adopted by the United
Nations University, International Institute for Global Health, for
the implementations and trainings.

This is the server component of GNU Health. 
You would need the Tryton frontend as well, on the same or a different machine


%prep
%setup -q -n %{name}-%{version}
#%patch0 -p1
cp %{S:1} .
cp %{S:2} .

%build
#export LANG=en_US.UTF-8
#export LC_CTYPE=en_US.UTF-8
#export RC_LANG=en_US.UTF-8
for i in h*; do
  cd $i
  python3 setup.py build
  cd ..
done
#pdq
#  cd pdq
#  python3 setup.py build
#  cd ..
for i in try*; do
  cd $i
  python3 setup.py build
  cd ..
done

%install
for i in h*; do
  cd $i
  python3 setup.py install --prefix=%_prefix --root=%buildroot 
  cd ..
done
#pdq
#  cd pdq
#  python3 setup.py install --prefix=%_prefix --root=%buildroot 
#  cd ..
for i in try*; do
  cd $i
    python3 setup.py install --prefix=%_prefix --root=%buildroot 
  cd ..
done

mkdir -p -m 755 %{buildroot}%{_bindir}
install -p -m 755 gnuhealth-control %{buildroot}%{_bindir}/gnuhealth-control

mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -p -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_unitdir}/%{name}.service
install -p -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{_unitdir}/%{name}-webdav@.service

%fdupes -s %{buildroot}

%pre
#Write environment changes to /etc/bash.bashrc.local
cat > /etc/bash.bashrc.local << "EOF"
alias cdlogs='cd /var/log/tryton'
alias cdexe='cd $(ls -d /usr/lib/python3.* )/site-packages/trytond'
alias cdconf='cd /etc/tryton'
alias cdmods='cd $(ls -d /usr/lib/python3.* )/site-packages/trytond/modules'
alias editconf='${EDITOR} /etc/tryton/trytond.conf'
alias cdutil='cd /usr/bin'
EOF

%service_add_pre gnuhealth.service
%service_add_pre gnuhealth-webdav@.service

%post
%service_add_post gnuhealth.service
%service_add_post gnuhealth-webdav@.service

%preun
%service_del_preun gnuhealth.service

%postun
%service_del_postun gnuhealth.service

%files 
%defattr(744,root,root)
%{_bindir}/gnuhealth-control
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}-webdav@.service
%defattr(-,root,root)
%doc README Changelog COPYING gnuhealth-setup version gnuhealthrc GNUHealth.README.SUSE scripts/* backend/* config/* doc/*
%{python_sitelib}/*

%changelog
* Wed Nov 15 2017 axel.braun@gmx.de
- removed pypi dependencies
* Wed Nov 15 2017 axel.braun@gmx.de
- health_crypto. Fix bug #52366: Error when signing the death certificate
  task #14626: Renaming Package names prefix trytond_ from Pypi. Update descriptions
  task #14626: Renaming Package names prefix trytond_ from Pypi. Remove tryton from keywords
  remove lingering egg-info dirs from webdav3
* Sun Oct 29 2017 axel.braun@gmx.de
- Version 3.2.6
  dependency on python3-pymongo removed
  fix bug #52298: Traceback generating an invoice from service with an insurance policy plan
  Fix bug #52275: Traceback when creating a free slot in appointments or work schedule
* Wed Oct 18 2017 axel.braun@gmx.de
- Correction for gnuhealth-control (file not found in backup)
* Sun Oct  8 2017 axel.braun@gmx.de
- version 3.2.5
  health, health_qrcodes : Fix bug #52179: Traceback due to obsolete unicode method in reports
* Wed Oct  4 2017 axel.braun@gmx.de
- Version 3.2.4
  health_services: Fix bug #52160: Issues related to invoice type and domain when creating the service invoice
  health_disability : Rename anf fix  Amputation model description from Amputation to Prothesis
  health : Prescription report . Include duration frequency selections strings for translation. Update conditional op. to Python3 (!=)
* Wed Sep 27 2017 axel.braun@gmx.de
- gnuhealth-control corrected (message command)
* Sat Sep 16 2017 axel.braun@gmx.de
- version 3.2.3 Fix bug #52038: Field history is repeated in the tree
  view of the prescription line
* Thu Sep 14 2017 axel.braun@gmx.de
- Documentation adapted
* Mon Aug 28 2017 axel.braun@gmx.de
- version 3.2.2
  health_imaging : Update health professional retrieval to the current standard method
* Tue Aug  8 2017 axel.braun@gmx.de
- added gnuhealth-webdav@.service
- updated documentation on gnuhealth-webdav@.service
- added alias cdutil for compatibility reasons (not really needed,
  as binaries are in /usr/bin anyway)
- fixed path for cdexe
* Sat Jul 22 2017 axel.braun@gmx.de
- version 3.2.1
  Fix view error on lab order
* Tue Jul 11 2017 axel.braun@gmx.de
- update of documentation for upgrade from Leap 42.2
* Sun Jul  2 2017 axel.braun@gmx.de
- Version 3.2.0
* Sat Jun 24 2017 axel.braun@gmx.de
- Requirement on python3-PyWebDAV3-GNUHealth added
* Tue Jun 20 2017 axel.braun@gmx.de
- GNU Health version 3.1.0b3
* Sun Mar 26 2017 axel.braun@gmx.de
- release 3.0.8
  [bug #50635] Missing declaration of view directory on setup.py on health_disability module
* Tue Mar 14 2017 axel.braun@gmx.de
- Release 3.0.7 (bnc1026365)
* Sat Feb 25 2017 axel.braun@gmx.de
- added DB-role to gnuhealh-control
  updated documentation
* Mon Feb 20 2017 axel.braun@gmx.de
- renamed gnuhealth_control to gnuhealth-control
  fixed documentation
* Tue Feb 14 2017 axel.braun@gmx.de
- version 3.06
  * Fix bug #50269: Traceback when assigning a new meal order
  * Fix bug #50281: Traceback when displaying patient critical info
    in non-english languages
  * fix bug #50288: Wrong widget for mealtime field. // Fix
    validation for meal order warning
  * Remove readonly from patient meal order warning, to correctly
    save state of the field
* Mon Dec 12 2016 axel.braun@gmx.de
- Release 3.0.5
  * Update to ICD10 version 2016
  * fix bug #49414: Error when printing prescription using review dates
  * bug #49405: Error on summary report when no date of birh is assigned to the person
* Sat Oct 22 2016 axel.braun@gmx.de
- temporary fix for prescription_orders report until 3.0.5 is released
* Sat Oct 22 2016 axel.braun@gmx.de
- Release 3.0.4
* Tue Oct 18 2016 axel.braun@gmx.de
- README updated
* Wed Sep 28 2016 axel.braun@gmx.de
- update of README.SUSE
* Wed Aug 31 2016 axel.braun@gmx.de
- file permissions corrected
* Sun Aug 21 2016 jengelh@inai.de
- Trim summary/description from redundant words
* Mon Jan 11 2016 axel.braun@gmx.de
- version 3.0.0
* Mon Jan  4 2016 axel.braun@gmx.de
- Version 3.0RC2
* Thu Jan 22 2015 axel.braun@gmx.de
- version 2.8
* Thu Jul 10 2014 axel.braun@gmx.de
- Release 2.6.0
* Wed Jan 22 2014 axel.braun@gmx.de
- GnuHealth 2.4RC1 on Tryton 3.0
* Fri Oct 18 2013 axel.braun@gmx.de
- Initial package build on OBS ( version 2.2.1 )
